"""workspaces-init

Revision ID: 44d5bbbf2615
Revises: 
Create Date: 2020-09-02 11:25:01.571392

"""
from alembic import op
import sqlalchemy as sa

revision = '44d5bbbf2615'
down_revision = None
branch_labels = None
depends_on = None


def upgrade():
    op.create_table('workflows',
                    sa.Column('workflow_id', sa.Integer, primary_key=True, autoincrement=True,
                              comment='the unique id of the workflow. auto-generated.'),
                    sa.Column('name', sa.String, unique=True, comment='a human-readable name for the workflow.'),
                    comment='A listing of the available workflows in the system.')

    op.create_table('workflow_requests',
                    sa.Column('workflow_request_id', sa.Integer, primary_key=True, autoincrement=True,
                              comment='the unique id of the request. auto-generated'),
                    sa.Column('job_id', sa.Integer,
                              comment='the id of the job that this request generted in the HTCondor system.'),
                    sa.Column('workflow_id', sa.Integer, sa.ForeignKey('workflows.workflow_id'),
                              comment='the id of the workflow used in this request.'),
                    sa.Column('argument', sa.JSON, comment='the argument(s) used for the workflow in this request.'),
                    comment='A listing of requests for workflows and te resulting job ids.')

    op.create_table('workflow_request_files',
                    sa.Column('workflow_request_id', sa.Integer, sa.ForeignKey('workflow_requests.workflow_request_id'),
                              comment='the id of the workflow request.'),
                    sa.Column('filename', sa.String, comment='the name of this file', nullable=False),
                    sa.Column('content', sa.String, comment='the contents of the file', nullable=False),
                    comment='A man-to-many mapping table tracking which files were used for workflow requests.')
    op.create_unique_constraint('workflow_request_filenames_uniq', 'workflow_request_files',
                                ['workflow_request_id', 'filename'])


def downgrade():
    op.drop_table('workflow_request_files')
    op.drop_table('workflow_requests')
    op.drop_table('workflows')